<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Adaugare Plugin-uri</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Cautare:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="102"/>
        <source>Add Widget</source>
        <translation>Adaugare Widget</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="112"/>
        <source>Close</source>
        <translation>Inchidere</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(o singura instanta poate rula in acelasi timp)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Configurează panoul</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="39"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="43"/>
        <source>Styling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="47"/>
        <source>Widgets</source>
        <translation>Widget-uri</translation>
    </message>
</context>
<context>
    <name>ConfigPlacement</name>
    <message>
        <location filename="../config/configplacement.ui" line="20"/>
        <source>Configure Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="44"/>
        <source>Size</source>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Pentru valori negative, dimensiunea panoului va fi calculată ca diferenta dintre marimea disponibilă a ecranului și valoarea introdusă.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;De ex. introducând o &quot;lungime&quot; de -100 px si o dimensiune a ecranului de 1000 px, dimensiunea reala a panoului va fi de 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="81"/>
        <source>Size:</source>
        <translation>Dimensiune:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="88"/>
        <source>Length:</source>
        <translation>Lungime:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="109"/>
        <location filename="../config/configplacement.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Dimensiune pictograme:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="173"/>
        <source>Rows:</source>
        <translation>Randuri:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Aliniere și poziție</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Aliniere:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="219"/>
        <location filename="../config/configplacement.cpp" line="188"/>
        <source>Left</source>
        <translation>Stânga</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="224"/>
        <location filename="../config/configplacement.cpp" line="189"/>
        <location filename="../config/configplacement.cpp" line="195"/>
        <source>Center</source>
        <translation>Centru</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="229"/>
        <location filename="../config/configplacement.cpp" line="190"/>
        <source>Right</source>
        <translation>Dreapta</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="237"/>
        <source>Position:</source>
        <translation>Poziție:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>Auto-ascundere</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="262"/>
        <location filename="../config/configplacement.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Zero inseamna Fara Animatie</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Durata animatiei:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="288"/>
        <location filename="../config/configplacement.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="301"/>
        <location filename="../config/configplacement.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Zero insemana Fara Decalaj</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Afiseaza cu Decalaj:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>Bordură subțire vizibilă pentru panoul ascuns</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="334"/>
        <source>Hide only on overlapping a window</source>
        <translation>Ascundeți numai dacă se suprapune o fereastră</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="344"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Nu permite ferestrelor maximizate sa intre sub fereastra panou</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="347"/>
        <source>Reserve space on display</source>
        <translation>Rezervă spatiu pe ecran</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="154"/>
        <source>Top of screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="155"/>
        <source>Left of screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="156"/>
        <source>Right of screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="157"/>
        <source>Bottom of screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="166"/>
        <source>Top of screen %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="167"/>
        <source>Left of screen %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="168"/>
        <source>Right of screen %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="169"/>
        <source>Bottom of screen %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="194"/>
        <source>Top</source>
        <translation>Sus</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="196"/>
        <source>Bottom</source>
        <translation>Jos</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Configureaza plugin-urile</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Nota: modificarile efectuate in aceasta pagina nu pot fi resetate.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Muta in sus</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Muta in jos</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Adauga</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Configurează</translation>
    </message>
</context>
<context>
    <name>ConfigStyling</name>
    <message>
        <location filename="../config/configstyling.ui" line="20"/>
        <source>Configure Styling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="44"/>
        <source>Custom styling</source>
        <translation>Stil particularizat</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="65"/>
        <source>Font color:</source>
        <translation>Culoare font:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="105"/>
        <source>Background color:</source>
        <translation>Culoare de fundal:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="144"/>
        <source>Background opacity:</source>
        <translation>Opacitatea fundalului:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="176"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Este necesar un compozitor pentru transparența tabloului de bord.&lt;/ small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="204"/>
        <source>Background image:</source>
        <translation>Imagine de fundal:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="256"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>O soluție parțială pentru stilurile de widget care
nu pot da o temă separată panoului.

Ați putea dori, de asemenea, să dezactivați:

Configurarea aspectului LXQt →
Tema pictograme →
Colorează pictogramele pe baza stilului widgetului (paletei)</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="266"/>
        <source>Override icon &amp;theme</source>
        <translation>Inlocuieste pictograma &amp;tema</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="281"/>
        <source>Icon theme for panels:</source>
        <translation>Tema de pictograme pentru panouri:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="189"/>
        <location filename="../config/configstyling.cpp" line="205"/>
        <source>Pick color</source>
        <translation>Alege culoare</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Pick image</source>
        <translation>Alege imagine</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Images (*.png *.gif *.jpg *.svg)</source>
        <translation>Imagini (*.png *.gif *.jpg *.svg)</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1495"/>
        <location filename="../lxqtpanel.cpp" line="1521"/>
        <source>Panel</source>
        <translation>Panou</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1524"/>
        <source>Configure Panel</source>
        <translation>Configurează panoul</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1529"/>
        <source>Manage Widgets</source>
        <translation>Gestionează Widget-uri</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1535"/>
        <source>Add New Panel</source>
        <translation>Adauga Panou nou</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1542"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Șterge Panou</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1547"/>
        <source>Lock This Panel</source>
        <translation>Blocheaza acest Panou</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1710"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Șterge panou</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1711"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Înlăturarea acestui panou nu poate fi anulata.
Doriți sa înlăturați acest panou?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="455"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Configurează &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="460"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Mută &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="468"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Îndepărtează &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="340"/>
        <source>Use alternate configuration file.</source>
        <translation>Utilizează fișierul de configurare alternativ.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="341"/>
        <source>Configuration file</source>
        <translation>Fisier de configurare</translation>
    </message>
</context>
</TS>
